@@ -1,8 +1,7 @@
 # Converted from WaitObject.template located at:
 # http://aws.amazon.com/cloudformation/aws-cloudformation-templates/
 
-from troposphere import FindInMap, GetAtt, Join, Output
-from troposphere import Parameter, Ref, Template
+from troposphere import GetAtt, Output, Ref, Template
 from troposphere.cloudformation import WaitCondition, WaitConditionHandle
 
 
@@ -40,4 +39,4 @@ t.add_output([
     )
 ])
 
-print t.to_json()
+print(t.to_json())
